Welcome to miditk-smf's documentation!
===========================================================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   install
   tests
   api
   license
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
